Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorEike Stepper2010-02-19 08:42:37 +0000
committerEike Stepper2010-02-19 08:42:37 +0000
commit537c15d7630a03bfa089eac1efd991679834395b (patch)
tree429469c32ba9a438db0259ec0c03bb873d02a7d7 /plugins/org.eclipse.emf.cdo.tests.model3/src
parent54d7b51c400797617dfa3b6ded279a51ab7d5231 (diff)
downloadcdo-537c15d7630a03bfa089eac1efd991679834395b.tar.gz
cdo-537c15d7630a03bfa089eac1efd991679834395b.tar.xz
cdo-537c15d7630a03bfa089eac1efd991679834395b.zip
[303279] Problem with CDOStore's toArray() implementation
https://bugs.eclipse.org/bugs/show_bug.cgi?id=303279
Diffstat (limited to 'plugins/org.eclipse.emf.cdo.tests.model3/src')
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/Model3Package.java18
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/Model3PackageImpl.java6
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/PolygonImpl.java38
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java18
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Polygon.java12
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/Model3PackageImpl.java6
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/PolygonImpl.java6
7 files changed, 52 insertions, 52 deletions
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/Model3PackageImpl.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/Model3PackageImpl.java
index e869eda53f..2dfff7e7f9 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/Model3PackageImpl.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/Model3PackageImpl.java
@@ -192,7 +192,7 @@ public class Model3PackageImpl extends EPackageImpl implements Model3Package
*
* @generated
*/
- public EAttribute getPolygon_Point()
+ public EAttribute getPolygon_Points()
{
return (EAttribute)polygonEClass.getEStructuralFeatures().get(0);
}
@@ -246,7 +246,7 @@ public class Model3PackageImpl extends EPackageImpl implements Model3Package
createEReference(metaRefEClass, META_REF__EPACKAGE_REF);
polygonEClass = createEClass(POLYGON);
- createEAttribute(polygonEClass, POLYGON__POINT);
+ createEAttribute(polygonEClass, POLYGON__POINTS);
// Create data types
pointEDataType = createEDataType(POINT);
@@ -304,7 +304,7 @@ public class Model3PackageImpl extends EPackageImpl implements Model3Package
IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(polygonEClass, Polygon.class, "Polygon", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getPolygon_Point(), getPoint(), "Point", null, 1, -1, Polygon.class, !IS_TRANSIENT, !IS_VOLATILE,
+ initEAttribute(getPolygon_Points(), getPoint(), "points", null, 1, -1, Polygon.class, !IS_TRANSIENT, !IS_VOLATILE,
IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
// Initialize data types
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/Model3PackageImpl.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/Model3PackageImpl.java
index 6295c23552..8286fb94ed 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/Model3PackageImpl.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/Model3PackageImpl.java
@@ -192,7 +192,7 @@ public class Model3PackageImpl extends EPackageImpl implements Model3Package
*
* @generated
*/
- public EAttribute getPolygon_Point()
+ public EAttribute getPolygon_Points()
{
return (EAttribute)polygonEClass.getEStructuralFeatures().get(0);
}
@@ -246,7 +246,7 @@ public class Model3PackageImpl extends EPackageImpl implements Model3Package
createEReference(metaRefEClass, META_REF__EPACKAGE_REF);
polygonEClass = createEClass(POLYGON);
- createEAttribute(polygonEClass, POLYGON__POINT);
+ createEAttribute(polygonEClass, POLYGON__POINTS);
// Create data types
pointEDataType = createEDataType(POINT);
@@ -304,7 +304,7 @@ public class Model3PackageImpl extends EPackageImpl implements Model3Package
IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(polygonEClass, Polygon.class, "Polygon", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getPolygon_Point(), getPoint(), "Point", null, 1, -1, Polygon.class, !IS_TRANSIENT, !IS_VOLATILE,
+ initEAttribute(getPolygon_Points(), getPoint(), "points", null, 1, -1, Polygon.class, !IS_TRANSIENT, !IS_VOLATILE,
IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
// Initialize data types
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/PolygonImpl.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/PolygonImpl.java
index ce9392390c..f30ef43713 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/PolygonImpl.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/impl/PolygonImpl.java
@@ -24,7 +24,7 @@ import org.eclipse.emf.ecore.EClass;
* <p>
* The following features are implemented:
* <ul>
- * <li>{@link org.eclipse.emf.cdo.tests.model3.impl.PolygonImpl#getPoint <em>Point</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.tests.model3.impl.PolygonImpl#getPoints <em>Points</em>}</li>
* </ul>
* </p>
*
@@ -70,9 +70,9 @@ public class PolygonImpl extends CDOObjectImpl implements Polygon
* @generated
*/
@SuppressWarnings("unchecked")
- public EList<Point> getPoint()
+ public EList<Point> getPoints()
{
- return (EList<Point>)eGet(Model3Package.Literals.POLYGON__POINT, true);
+ return (EList<Point>)eGet(Model3Package.Literals.POLYGON__POINTS, true);
}
} // PolygonImpl

Back to the top
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/Model3Package.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/Model3Package.java
index 162314bede..4b33231c96 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/Model3Package.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/Model3Package.java
@@ -122,12 +122,12 @@ public interface Model3Package extends org.eclipse.emf.cdo.tests.model3.Model3Pa
int POLYGON = 2;
/**
* The feature id for the '<em><b>Point</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int POLYGON__POINT = 0;
+ int POLYGON__POINTS = 0;
/**
* The number of structural features of the '<em>Polygon</em>' class. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -199,15 +199,15 @@ public interface Model3Package extends org.eclipse.emf.cdo.tests.model3.Model3Pa
EClass getPolygon();
/**
* Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.legacy.model3.Polygon#getPoint
* <em>Point</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @return the meta object for the attribute list '<em>Point</em>'.
* @see org.eclipse.emf.cdo.tests.legacy.model3.Polygon#getPoint()
* @see #getPolygon()
* @generated
*/
- EAttribute getPolygon_Point();
+ EAttribute getPolygon_Points();
/**
* Returns the meta object for data type '{@link org.eclipse.emf.cdo.tests.model3.Point <em>Point</em>}'. <!--
@@ -289,12 +289,12 @@ public interface Model3Package extends org.eclipse.emf.cdo.tests.model3.Model3Pa
EClass POLYGON = eINSTANCE.getPolygon();
/**
* The meta object literal for the '<em><b>Point</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
* @generated
*/
- EAttribute POLYGON__POINT = eINSTANCE.getPolygon_Point();
+ EAttribute POLYGON__POINTS = eINSTANCE.getPolygon_Points();
/**
* The meta object literal for the '<em>Point</em>' data type. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -122,12 +122,12 @@ public interface Model3Package extends org.eclipse.emf.cdo.tests.model3.Model3Pa
int POLYGON = 2;
/**
- * The feature id for the '<em><b>Point</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Points</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
@@ -199,15 +199,15 @@ public interface Model3Package extends org.eclipse.emf.cdo.tests.model3.Model3Pa
EClass getPolygon();
/**
- * Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.legacy.model3.Polygon#getPoint
- * <em>Point</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.legacy.model3.Polygon#getPoints
+ * <em>Points</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
@@ -199,15 +199,15 @@ public interface Model3Package extends org.eclipse.emf.cdo.tests.model3.Model3Pa
*
- * @return the meta object for the attribute list '<em>Point</em>'.
- * @see org.eclipse.emf.cdo.tests.legacy.model3.Polygon#getPoint()
+ * @return the meta object for the attribute list '<em>Points</em>'.
+ * @see org.eclipse.emf.cdo.tests.legacy.model3.Polygon#getPoints()
* @see #getPolygon()
* @generated
@@ -289,12 +289,12 @@ public interface Model3Package extends org.eclipse.emf.cdo.tests.model3.Model3Pa
EClass POLYGON = eINSTANCE.getPolygon();
/**
- * The meta object literal for the '<em><b>Point</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
+ * The meta object literal for the '<em><b>Points</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/PolygonImpl.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/PolygonImpl.java
index 2375029a20..daa4a6fd61 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/PolygonImpl.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/legacy/model3/impl/PolygonImpl.java
@@ -26,7 +26,7 @@ import java.util.Collection;
* <p>
* The following features are implemented:
* <ul>
- * <li>{@link org.eclipse.emf.cdo.tests.legacy.model3.impl.PolygonImpl#getPoint <em>Point</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.tests.legacy.model3.impl.PolygonImpl#getPoints <em>Points</em>}</li>
* </ul>
* </p>
*
@@ -35,14 +35,14 @@ import java.util.Collection;
public class PolygonImpl extends EObjectImpl implements Polygon
{
/**
* The cached value of the '{@link #getPoint() <em>Point</em>}' attribute list. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
- * @see #getPoint()
+ * @see #getPoints()
* @generated
* @ordered
*/
- protected EList<Point> point;
+ protected EList<Point> points;
/**
* <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -70,13 +70,13 @@ public class PolygonImpl extends EObjectImpl implements Polygon
*
* @generated
*/
- public EList<Point> getPoint()
+ public EList<Point> getPoints()
{
- if (point == null)
+ if (points == null)
{
- point = new EDataTypeUniqueEList<Point>(Point.class, this, Model3Package.POLYGON__POINT);
+ points = new EDataTypeUniqueEList<Point>(Point.class, this, Model3Package.POLYGON__POINTS);
}
- return point;
+ return points;
}
/**
@@ -89,8 +89,8 @@ public class PolygonImpl extends EObjectImpl implements Polygon
{
switch (featureID)
{
- case Model3Package.POLYGON__POINT:
- return getPoint();
+ case Model3Package.POLYGON__POINTS:
+ return getPoints();
}
return super.eGet(featureID, resolve, coreType);
}
@@ -106,9 +106,9 @@ public class PolygonImpl extends EObjectImpl implements Polygon
{
switch (featureID)
{
- case Model3Package.POLYGON__POINT:
- getPoint().clear();
- getPoint().addAll((Collection<? extends Point>)newValue);
+ case Model3Package.POLYGON__POINTS:
+ getPoints().clear();
+ getPoints().addAll((Collection<? extends Point>)newValue);
return;
}
super.eSet(featureID, newValue);
@@ -124,8 +124,8 @@ public class PolygonImpl extends EObjectImpl implements Polygon
{
switch (featureID)
{
- case Model3Package.POLYGON__POINT:
- getPoint().clear();
+ case Model3Package.POLYGON__POINTS:
+ getPoints().clear();
return;
}
super.eUnset(featureID);
@@ -141,8 +141,8 @@ public class PolygonImpl extends EObjectImpl implements Polygon
{
switch (featureID)
{
- case Model3Package.POLYGON__POINT:
- return point != null && !point.isEmpty();
+ case Model3Package.POLYGON__POINTS:
+ return points != null && !points.isEmpty();
}
return super.eIsSet(featureID);
}
@@ -161,8 +161,8 @@ public class PolygonImpl extends EObjectImpl implements Polygon
}
StringBuffer result = new StringBuffer(super.toString());
- result.append(" (Point: ");
- result.append(point);
+ result.append(" (points: ");
+ result.append(points);
result.append(')');
return result.toString();
}
@@ -35,14 +35,14 @@ import java.util.Collection;
{
/**
- * The cached value of the '{@link #getPoint() <em>Point</em>}' attribute list. <!-- begin-user-doc --> <!--
+ * The cached value of the '{@link #getPoints() <em>Points</em>}' attribute list. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java
index 71c0d237da..923caec79f 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java
@@ -123,12 +123,12 @@ public interface Model3Package extends EPackage
int POLYGON = 2;
/**
* The feature id for the '<em><b>Point</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int POLYGON__POINT = 0;
+ int POLYGON__POINTS = 0;
/**
* The number of structural features of the '<em>Polygon</em>' class. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -200,15 +200,15 @@ public interface Model3Package extends EPackage
EClass getPolygon();
/**
* Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoint
* <em>Point</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @return the meta object for the attribute list '<em>Point</em>'.
* @see org.eclipse.emf.cdo.tests.model3.Polygon#getPoint()
* @see #getPolygon()
* @generated
*/
- EAttribute getPolygon_Point();
+ EAttribute getPolygon_Points();
/**
* Returns the meta object for data type '{@link org.eclipse.emf.cdo.tests.model3.Point <em>Point</em>}'. <!--
@@ -290,12 +290,12 @@ public interface Model3Package extends EPackage
EClass POLYGON = eINSTANCE.getPolygon();
/**
* The meta object literal for the '<em><b>Point</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
* @generated
*/
- EAttribute POLYGON__POINT = eINSTANCE.getPolygon_Point();
+ EAttribute POLYGON__POINTS = eINSTANCE.getPolygon_Points();
/**
* The meta object literal for the '<em>Point</em>' data type. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -123,12 +123,12 @@ public interface Model3Package extends EPackage
int POLYGON = 2;
/**
- * The feature id for the '<em><b>Point</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Points</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
@@ -200,15 +200,15 @@ public interface Model3Package extends EPackage
EClass getPolygon();
/**
- * Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoint
- * <em>Point</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoints
+ * <em>Points</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
@@ -200,15 +200,15 @@ public interface Model3Package extends EPackage
*
- * @return the meta object for the attribute list '<em>Point</em>'.
- * @see org.eclipse.emf.cdo.tests.model3.Polygon#getPoint()
+ * @return the meta object for the attribute list '<em>Points</em>'.
+ * @see org.eclipse.emf.cdo.tests.model3.Polygon#getPoints()
* @see #getPolygon()
* @generated
@@ -290,12 +290,12 @@ public interface Model3Package extends EPackage
EClass POLYGON = eINSTANCE.getPolygon();
/**
- * The meta object literal for the '<em><b>Point</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
+ * The meta object literal for the '<em><b>Points</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Polygon.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Polygon.java
index 350d42810d..1146a5731c 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Polygon.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Polygon.java
@@ -18,7 +18,7 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoint <em>Point</em>}</li>
+ * <li>{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoints <em>Points</em>}</li>
* </ul>
* </p>
*
@@ -29,19 +29,19 @@ import org.eclipse.emf.ecore.EObject;
public interface Polygon extends EObject
{
/**
* Returns the value of the '<em><b>Point</b></em>' attribute list. The list contents are of type
* {@link org.eclipse.emf.cdo.tests.model3.Point}. <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Point</em>' attribute list isn't clear, there really should be more of a description
* here...
* </p>
* <!-- end-user-doc -->
*
* @return the value of the '<em>Point</em>' attribute list.
* @see org.eclipse.emf.cdo.tests.model3.Model3Package#getPolygon_Point()
* @model dataType="org.eclipse.emf.cdo.tests.model3.Point" required="true"
* @generated
*/
- EList<Point> getPoint();
+ EList<Point> getPoints();
} // Polygon
@@ -29,19 +29,19 @@ import org.eclipse.emf.ecore.EObject;
{
/**
- * Returns the value of the '<em><b>Point</b></em>' attribute list. The list contents are of type
+ * Returns the value of the '<em><b>Points</b></em>' attribute list. The list contents are of type
* {@link org.eclipse.emf.cdo.tests.model3.Point}. <!-- begin-user-doc -->
* <p>
@@ -29,19 +29,19 @@ import org.eclipse.emf.ecore.EObject;
* {@link org.eclipse.emf.cdo.tests.model3.Point}. <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Point</em>' attribute list isn't clear, there really should be more of a description
+ * If the meaning of the '<em>Points</em>' attribute list isn't clear, there really should be more of a description
* here...
* </p>
@@ -29,19 +29,19 @@ import org.eclipse.emf.ecore.EObject;
* <!-- end-user-doc -->
*
- * @return the value of the '<em>Point</em>' attribute list.
- * @see org.eclipse.emf.cdo.tests.model3.Model3Package#getPolygon_Point()
+ * @return the value of the '<em>Points</em>' attribute list.
+ * @see org.eclipse.emf.cdo.tests.model3.Model3Package#getPolygon_Points()
* @model dataType="org.eclipse.emf.cdo.tests.model3.Point" required="true"
* @generated